@@ -45,11 +45,16 @@ def removeWebProtocol(Address: str):
         raise ERROR("There is not a web protocol.")    
 
 def isOnline(Address: str):
+    # IMPORT
+    from scapy.all import sr1
+    from scapy.layers.inet import IP, ICMP
+    import socket
+
     # RUN & RETURN
     try:
-        if get(getfqdn(Address)).status_code == 200:
-            return True
-        else:
+        if sr1(IP(dst = socket.gethostbyname(Address))/ICMP(), timeout = 1, verbose = 0) is None:
             return False
+        else:
+            return True
     except:
         return False
